# pyMetaModel
migrates https://wiki.bitplan.com/index.php/MetaModel#tab=Model to python

[![Join the discussion at https://github.com/WolfgangFahl/pyMetaModel/discussions](https://img.shields.io/github/discussions/WolfgangFahl/pyMetaModel)](https://github.com/WolfgangFahl/pyMetaModel/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/pyMetaModel)](https://pypi.org/project/pyMetaModel/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyMetaModel/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/pyMetaModel/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/pyMetaModel.svg)](https://pypi.python.org/pypi/pyMetaModel/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyMetaModel.svg)](https://github.com/WolfgangFahl/pyMetaModel/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyMetaModel.svg)](https://github.com/WolfgangFahl/pyMetaModel/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/pyMetaModel/)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyMetaModel.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Introduction
pyMetaModel is a python library for a Knowledge Graph MetaModel

It started with the ProfiWiki [SemanticMediaWiki MetaModel](https://wiki.bitplan.com/index.php/MetaModel#tab=topics) in
2015 consisting of

- Context
- Topic
- TopicLink
- Property
- Action
- SMWType


## Documentation
[Wiki](http://wiki.bitplan.com/index.php/pyMetaModel)

### Model
![Class Diagram](http://www.plantuml.com/plantuml/proxy?src=https://raw.githubusercontent.com/WolfgangFahl/pyMetaModel/main/metamodel.puml?fmt=svg&version=4)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
